Documentation
¶
Overview ¶
Copyright (c) 2015-2016 The GoAnalysis Authors. All rights reserved. Use of this source code is governed by a BSD-style license that can be found in the LICENSE file.
Index ¶
Constants ¶
const CC_LIMIT = 10 // Upper limit of cyclomatic complexity measures.
const ERROR_OUTPUT_FILE = "GoAnalyzerError.log"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GoFile ¶
type GoFile struct {
FilePath string
LinesOfCode int
LinesOfComments int
Violations []*Violation
// contains filtered or unexported fields
}
type GoPackage ¶
type GoPackage struct {
Violations []*GoFile
Path string
Pack *ast.Package
// contains filtered or unexported fields
}
func DetectViolations ¶
func (*GoPackage) GetFileNodes ¶
type Rule ¶
type Rule int
const ( RACE_CONDITION Rule = iota FMT_PRINTING STRING_CALLS_ITSELF MAP_ALLOCATED_WITH_NEW ERROR_IGNORED EMPTY_IF_BODY EMPTY_ELSE_BODY EMPTY_FOR_BODY GOTO_USED CONDITION_EVALUATED_STATICALLY BUFFER_NOT_FLUSHED RETURN_KILLS_CODE CYCLOMATIC_COMPLEXITY )
Rules.
func (Rule) MarshalText ¶
Marshal Rule string value instead of int value.
Directories
¶
| Path | Synopsis |
|---|---|
|
graph/stack
Package graph.stack provides an implementation of the Stack abstract-datastructure, basically providing the standard graph.stack operating primitives.
|
Package graph.stack provides an implementation of the Stack abstract-datastructure, basically providing the standard graph.stack operating primitives. |
|
testcode
|
|
|
bufferwriting
command
|
|
|
cyclomaticomplexity
command
|
|
|
earlyreturn
command
|
|
|
emptyelsebody
command
|
|
|
emptyforbody
command
|
|
|
emptyifbody
command
|
|
|
errorignored
command
|
|
|
errorinreturn
command
|
|
|
fmtprinting
command
|
|
|
goto
command
|
|
|
labeledbranch
command
|
|
|
newmap
command
|
|
|
staticconditions
command
|
|
|
stringmethod
command
|
|
|
threadlooping
command
|
Click to show internal directories.
Click to hide internal directories.